@@ -3,16 +3,36 @@
 """ General matlab interface code """
 import os
 
-from nipype.interfaces.base import CommandLineInputSpec, InputMultiPath
-from nipype.utils.misc import isdefined
-from nipype.interfaces.base import (CommandLine, traits, File, Directory)
-from nipype.utils.config import config
+from nipype.interfaces.base import (CommandLineInputSpec, InputMultiPath, isdefined,
+                                    CommandLine, traits, File, Directory)
+from .. import config
+
+def get_matlab_command():
+    if 'NIPYPE_NO_MATLAB' in os.environ:
+        return None
+
+    try:
+        matlab_cmd = os.environ['MATLABCMD']
+    except:
+        matlab_cmd = 'matlab'
+
+    try:
+        res = CommandLine(command='which', args=matlab_cmd).run()
+        matlab_path = res.runtime.stdout.strip()
+    except Exception, e:
+        return None
+    return matlab_cmd
+
+no_matlab = get_matlab_command() is None
 
 class MatlabInputSpec(CommandLineInputSpec):
     """ Basic expected inputs to Matlab interface """
-    
+
     script  = traits.Str(argstr='-r \"%s;exit\"', desc='m-code to run',
                          mandatory=True, position=-1)
+    uses_mcr = traits.Bool(desc='use MCR interface',
+                           xor=['nodesktop', 'nosplash',
+                                'single_comp_thread'])
     nodesktop = traits.Bool(True, argstr='-nodesktop',
                             usedefault=True,
                             desc='Switch off desktop mode on unix platforms')
@@ -23,11 +43,18 @@ class MatlabInputSpec(CommandLineInputSpec):
     single_comp_thread = traits.Bool(argstr="-singleCompThread",
                                    desc="force single threaded operation")
     # non-commandline options
-    mfile   = traits.Bool(False, desc='Run m-code using m-file',
+    mfile   = traits.Bool(True, desc='Run m-code using m-file',
                           usedefault=True)
     script_file = File('pyscript.m', usedefault=True,
                               desc='Name of file to write m-code to')
     paths   = InputMultiPath(Directory(), desc='Paths to add to matlabpath')
+    prescript = traits.List(["ver,","try,"], usedefault=True,
+                            desc='prescript to be added before code')
+    postscript = traits.List(["\n,catch ME,",
+                              "fprintf(2,'MATLAB code threw an exception:\\n');",
+                              "fprintf(2,'%s\\n',ME.message);",
+                              "if length(ME.stack) ~= 0, fprintf(2,'File:%s\\nName:%s\\nLine:%d\\n',ME.stack.file,ME.stack.name,ME.stack.line);, end;",
+                              "end;"], desc='script added after code', usedefault = True)
 
 class MatlabCommand(CommandLine):
     """Interface that runs matlab code
@@ -43,7 +70,7 @@ class MatlabCommand(CommandLine):
     _default_mfile = None
     _default_paths = None
     input_spec = MatlabInputSpec
-    
+
     def __init__(self, matlab_cmd = None, **inputs):
         """initializes interface to matlab
         (default 'matlab -nodesktop -nosplash')
@@ -53,17 +80,18 @@ class MatlabCommand(CommandLine):
             self._cmd = matlab_cmd
         elif self._default_matlab_cmd:
             self._cmd = self._default_matlab_cmd
-            
+
         if self._default_mfile and not isdefined(self.inputs.mfile):
             self.inputs.mfile = self._default_mfile
-            
+
         if self._default_paths and not isdefined(self.inputs.paths):
             self.inputs.paths = self._default_paths
-            
-        if not isdefined(self.inputs.single_comp_thread):
+
+        if not isdefined(self.inputs.single_comp_thread) and \
+                not isdefined(self.inputs.uses_mcr):
             if config.getboolean('execution','single_thread_matlab'):
                 self.inputs.single_comp_thread = True
-            
+
     @classmethod
     def set_default_matlab_cmd(cls, matlab_cmd):
         """Set the default MATLAB command line for MATLAB classes.
@@ -74,7 +102,7 @@ class MatlabCommand(CommandLine):
         <instance>.inputs.matlab_cmd.
         """
         cls._default_matlab_cmd = matlab_cmd
-        
+
     @classmethod
     def set_default_mfile(cls, mfile):
         """Set the default MATLAB script file format for MATLAB classes.
@@ -85,7 +113,7 @@ class MatlabCommand(CommandLine):
         <instance>.inputs.mfile.
         """
         cls._default_mfile = mfile
-        
+
     @classmethod
     def set_default_paths(cls, paths):
         """Set the default MATLAB paths for MATLAB classes.
@@ -99,53 +127,55 @@ class MatlabCommand(CommandLine):
 
     def _run_interface(self,runtime):
         runtime = super(MatlabCommand, self)._run_interface(runtime)
-        if 'command not found' in runtime.stderr:
-            msg = 'Cannot find matlab!\n' + \
-                '\tTried command:  ' + runtime.cmdline + \
-                '\n\tShell reported: ' + runtime.stderr
-            raise IOError(msg)
-        if  'MatlabScriptException' in runtime.stderr:
-            runtime.returncode = 1
+        try:
+            # Matlab can leave the terminal in a barbbled state
+            os.system('stty sane')
+        except:
+            # We might be on a system where stty doesn't exist
+            pass
+        if 'MATLAB code threw an exception' in runtime.stderr:
+            self.raise_exception(runtime)
         return runtime
 
     def _format_arg(self, name, trait_spec, value):
         if name in ['script']:
-            return self._gen_matlab_command(trait_spec.argstr, value)
+            argstr = trait_spec.argstr
+            if self.inputs.uses_mcr:
+                argstr='%s'
+            return self._gen_matlab_command(argstr, value)
         return super(MatlabCommand, self)._format_arg(name, trait_spec, value)
 
     def _gen_matlab_command(self, argstr, script_lines):
         cwd = os.getcwd()
-        mfile = self.inputs.mfile
+        mfile = self.inputs.mfile or self.inputs.uses_mcr
         paths = []
         if isdefined(self.inputs.paths):
             paths = self.inputs.paths
         # prescript
-        prescript  = ''
+        prescript = self.inputs.prescript
+        postscript = self.inputs.postscript
+
+        #postcript takes different default value depending on the mfile argument
         if mfile:
-            prescript += "fprintf(1,'Executing %s at %s:\\n',mfilename,datestr(now));\n"
+            prescript.insert(0,"fprintf(1,'Executing %s at %s:\\n',mfilename,datestr(now));")
         else:
-            prescript += "fprintf(1,'Executing code at %s:\\n',datestr(now));\n" 
-        prescript += "ver,\n"
-        prescript += "try,\n"
+            prescript.insert(0,"fprintf(1,'Executing code at %s:\\n',datestr(now));")
         for path in paths:
-            prescript += "addpath('%s');\n" % path
-        # postscript
-        postscript  = ''
-        postscript += "\n,catch ME,\n"
-        postscript += "ME,\n"
-        postscript += "ME.stack,\n"
-        postscript += "fprintf('%s\\n',ME.message);\n"
-        postscript += "fprintf(2,'<MatlabScriptException>');\n"
-        postscript += "fprintf(2,'%s\\n',ME.message);\n"
-        postscript += "fprintf(2,'File:%s\\nName:%s\\nLine:%d\\n',ME.stack.file,ME.stack.name,ME.stack.line);\n"
-        postscript += "fprintf(2,'</MatlabScriptException>');\n"
-        postscript += "end;\n"
-        script_lines = prescript+script_lines+postscript
+            prescript.append("addpath('%s');\n" % path)
+
+        if not mfile:
+            #clean up the code of comments and replace newlines with commas
+            script_lines = ','.join([line for line in script_lines.split("\n") if not line.strip().startswith("%")])
+
+        script_lines = '\n'.join(prescript)+script_lines+'\n'.join(postscript)
         if mfile:
             mfile = file(os.path.join(cwd,self.inputs.script_file), 'wt')
             mfile.write(script_lines)
             mfile.close()
-            script = "addpath('%s');%s" % (cwd, self.inputs.script_file.split('.')[0])
+            if self.inputs.uses_mcr:
+                script = '%s' % (os.path.join(cwd,self.inputs.script_file))
+            else:
+                script = "addpath('%s');%s" % (cwd, self.inputs.script_file.split('.')[0])
         else:
             script = ''.join(script_lines.split('\n'))
         return argstr % script
